package com.cmvr.device.service;

import java.util.List;
import com.cmvr.device.domain.DeDeviceTerminalConfig;

/**
 * 设备终端配置Service接口
 * 
 * @author cmvr-iot
 * @date 2025-05-08
 */
public interface IDeDeviceTerminalConfigService 
{
    /**
     * 查询设备终端配置
     * 
     * @param id 设备终端配置主键
     * @return 设备终端配置
     */
    public DeDeviceTerminalConfig selectDeDeviceTerminalConfigById(String id);

    /**
     * 查询设备终端配置列表
     * 
     * @param deDeviceTerminalConfig 设备终端配置
     * @return 设备终端配置集合
     */
    public List<DeDeviceTerminalConfig> selectDeDeviceTerminalConfigList(DeDeviceTerminalConfig deDeviceTerminalConfig);

    /**
     * 新增设备终端配置
     * 
     * @param deDeviceTerminalConfig 设备终端配置
     * @return 结果
     */
    public int insertDeDeviceTerminalConfig(DeDeviceTerminalConfig deDeviceTerminalConfig);

    /**
     * 修改设备终端配置
     * 
     * @param deDeviceTerminalConfig 设备终端配置
     * @return 结果
     */
    public int updateDeDeviceTerminalConfig(DeDeviceTerminalConfig deDeviceTerminalConfig);

    /**
     * 批量删除设备终端配置
     * 
     * @param ids 需要删除的设备终端配置主键集合
     * @return 结果
     */
    public int deleteDeDeviceTerminalConfigByIds(String[] ids);

    /**
     * 删除设备终端配置信息
     * 
     * @param id 设备终端配置主键
     * @return 结果
     */
    public int deleteDeDeviceTerminalConfigById(String id);
}
